@@ -15,6 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """Launches pods."""
+
 from __future__ import annotations
 
 import json
@@ -32,7 +33,7 @@ from requests.exceptions import HTTPError
 
 from airflow.exceptions import AirflowException, RemovedInAirflow3Warning
 from airflow.providers.cncf.kubernetes.kube_client import get_kube_client
-from airflow.providers.cncf.kubernetes.pod_generator import PodDefaults
+from airflow.providers.cncf.kubernetes.pod_generator import PodDefaultsDeprecated
 from airflow.settings import pod_mutation_hook
 from airflow.utils.log.logging_mixin import LoggingMixin
 from airflow.utils.state import State
@@ -119,7 +120,7 @@ class PodLauncher(LoggingMixin):
             )
         except ApiException as e:
             # If the pod is already deleted
-            if e.status != 404:
+            if str(e.status) != "404":
                 raise
 
     def start_pod(self, pod: V1Pod, startup_timeout: int = 120):
@@ -271,7 +272,7 @@ class PodLauncher(LoggingMixin):
             self._client.connect_get_namespaced_pod_exec,
             pod.metadata.name,
             pod.metadata.namespace,
-            container=PodDefaults.SIDECAR_CONTAINER_NAME,
+            container=PodDefaultsDeprecated.SIDECAR_CONTAINER_NAME,
             command=["/bin/sh"],
             stdin=True,
             stdout=True,
@@ -280,7 +281,7 @@ class PodLauncher(LoggingMixin):
             _preload_content=False,
         )
         try:
-            result = self._exec_pod_command(resp, f"cat {PodDefaults.XCOM_MOUNT_PATH}/return.json")
+            result = self._exec_pod_command(resp, f"cat {PodDefaultsDeprecated.XCOM_MOUNT_PATH}/return.json")
             self._exec_pod_command(resp, "kill -s SIGINT 1")
         finally:
             resp.close()
