@@ -19,11 +19,13 @@ from __future__ import annotations
 
 import warnings
 from datetime import datetime, timedelta
+from typing import Collection
 
 from croniter import croniter
 from dateutil.relativedelta import relativedelta  # for doctest
 
 from airflow.exceptions import RemovedInAirflow3Warning
+from airflow.typing_compat import Literal
 from airflow.utils import timezone
 
 cron_presets: dict[str, str] = {
@@ -43,9 +45,7 @@ def date_range(
     delta: str | timedelta | relativedelta | None = None,
 ) -> list[datetime]:
     """
-    Get a set of dates as a list based on a start, end and delta, delta
-    can be something that can be added to `datetime.datetime`
-    or a cron expression as a `str`
+    Get a list of dates in the specified range, separated by delta.
 
     .. code-block:: pycon
         >>> from airflow.utils.dates import date_range
@@ -80,9 +80,9 @@ def date_range(
         return []
     if end_date:
         if start_date > end_date:
-            raise Exception("Wait. start_date needs to be before end_date")
+            raise ValueError("Wait. start_date needs to be before end_date")
         if num:
-            raise Exception("Wait. Either specify end_date OR num")
+            raise ValueError("Wait. Either specify end_date OR num")
     if not end_date and not num:
         end_date = timezone.utcnow()
 
@@ -100,7 +100,7 @@ def date_range(
     elif isinstance(delta, relativedelta):
         abs_delta = abs(delta)
     else:
-        raise Exception("Wait. delta must be either datetime.timedelta or cron expression as str")
+        raise TypeError("Wait. delta must be either datetime.timedelta or cron expression as str")
 
     dates = []
     if end_date:
@@ -136,11 +136,13 @@ def date_range(
     return sorted(dates)
 
 
-def round_time(dt, delta, start_date=timezone.make_aware(datetime.min)):
+def round_time(
+    dt: datetime,
+    delta: str | timedelta | relativedelta,
+    start_date: datetime = timezone.make_aware(datetime.min),
+):
     """
-    Returns the datetime of the form start_date + i * delta
-    which is closest to dt for any non-negative integer i.
-    Note that delta may be a datetime.timedelta or a dateutil.relativedelta
+    Return ``start_date + i * delta`` for given ``i`` where the result is closest to ``dt``.
 
     .. code-block:: pycon
 
@@ -219,13 +221,16 @@ def round_time(dt, delta, start_date=timezone.make_aware(datetime.min)):
     # and this function returns start_date.
 
 
-def infer_time_unit(time_seconds_arr):
+TimeUnit = Literal["days", "hours", "minutes", "seconds"]
+
+
+def infer_time_unit(time_seconds_arr: Collection[float]) -> TimeUnit:
     """
-    Determine the most appropriate time unit for an array of time durations
-    specified in seconds.
+    Determine the most appropriate time unit for given durations (in seconds).
+
     e.g. 5400 seconds => 'minutes', 36000 seconds => 'hours'
     """
-    if len(time_seconds_arr) == 0:
+    if not time_seconds_arr:
         return "hours"
     max_time_seconds = max(time_seconds_arr)
     if max_time_seconds <= 60 * 2:
@@ -238,21 +243,24 @@ def infer_time_unit(time_seconds_arr):
         return "days"
 
 
-def scale_time_units(time_seconds_arr, unit):
+def scale_time_units(time_seconds_arr: Collection[float], unit: TimeUnit) -> Collection[float]:
     """Convert an array of time durations in seconds to the specified time unit."""
     if unit == "minutes":
-        return list(map(lambda x: x / 60, time_seconds_arr))
+        factor = 60
     elif unit == "hours":
-        return list(map(lambda x: x / (60 * 60), time_seconds_arr))
+        factor = 60 * 60
     elif unit == "days":
-        return list(map(lambda x: x / (24 * 60 * 60), time_seconds_arr))
-    return time_seconds_arr
+        factor = 24 * 60 * 60
+    else:
+        factor = 1
+    return [x / factor for x in time_seconds_arr]
 
 
 def days_ago(n, hour=0, minute=0, second=0, microsecond=0):
     """
-    Get a datetime object representing `n` days ago. By default the time is
-    set to midnight.
+    Get a datetime object representing *n* days ago.
+
+    By default the time is set to midnight.
     """
     warnings.warn(
         "Function `days_ago` is deprecated and will be removed in Airflow 3.0. "
@@ -268,3 +276,8 @@ def days_ago(n, hour=0, minute=0, second=0, microsecond=0):
 def parse_execution_date(execution_date_str):
     """Parse execution date string to datetime object."""
     return timezone.parse(execution_date_str)
+
+
+def datetime_to_nano(datetime) -> int:
+    """Convert datetime to nanoseconds."""
+    return int(datetime.timestamp() * 1000000000)
